pm4py.algo.discovery.heuristics package
=======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.heuristics.variants

Submodules
----------

pm4py.algo.discovery.heuristics.algorithm module
------------------------------------------------

.. automodule:: pm4py.algo.discovery.heuristics.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.heuristics.parameters module
-------------------------------------------------

.. automodule:: pm4py.algo.discovery.heuristics.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.heuristics
   :members:
   :undoc-members:
   :show-inheritance:
